summaryrefslogtreecommitdiff
path: root/framework/Web/UI/WebControls/THiddenField.php
diff options
context:
space:
mode:
authorxue <>2006-01-21 17:29:40 +0000
committerxue <>2006-01-21 17:29:40 +0000
commit3fcf847e0cadfb9ede930f538c2f277483442175 (patch)
tree12534cf4b29c1d4676fd59ab47adb60e292bcb6c /framework/Web/UI/WebControls/THiddenField.php
parent99b56c855a597c606d349c7063d843539e65a6ed (diff)
BE AWARE: Significant change!
Changed event definition from XXX to OnXXX.
Diffstat (limited to 'framework/Web/UI/WebControls/THiddenField.php')
-rw-r--r--framework/Web/UI/WebControls/THiddenField.php6
1 files changed, 3 insertions, 3 deletions
diff --git a/framework/Web/UI/WebControls/THiddenField.php b/framework/Web/UI/WebControls/THiddenField.php
index fe758c6b..7b112b0f 100644
--- a/framework/Web/UI/WebControls/THiddenField.php
+++ b/framework/Web/UI/WebControls/THiddenField.php
@@ -15,7 +15,7 @@
*
* THiddenField displays a hidden input field on a Web page.
* The value of the input field can be accessed via {@link getValue Value} property.
- * If upon postback the value is changed, a {@link onValueChanged ValueChanged}
+ * If upon postback the value is changed, a {@link onValueChanged OnValueChanged}
* event will be raised.
*
* @author Qiang Xue <qiang.xue@gmail.com>
@@ -94,14 +94,14 @@ class THiddenField extends TControl implements IPostBackDataHandler
/**
* This method is invoked when the value of the {@link getValue Value} property changes between posts to the server.
* The method raises 'ValueChanged' event to fire up the event delegates.
* If you override this method, be sure to call the parent implementation
* so that the attached event handlers can be invoked.
* @param TEventParameter event parameter to be passed to the event handlers
*/
public function onValueChanged($param)
{
- $this->raiseEvent('ValueChanged',$this,$param);
+ $this->raiseEvent('OnValueChanged',$this,$param);
}
/**
@@ -94,14 +94,14 @@ class THiddenField extends TControl implements IPostBackDataHandler
/**
* This method is invoked when the value of the {@link getValue Value} property changes between posts to the server.
- * The method raises 'ValueChanged' event to fire up the event delegates.
+ * The method raises 'OnValueChanged' event to fire up the event delegates.
* If you override this method, be sure to call the parent implementation
* so that the attached event handlers can be invoked.